# Atmosphyre
A Python package to characterise the impact of atmospheric dispersion on a spectrographs throughput.

Instructions can be found at readthedocs:
https://readthedocs.org/projects/atmosphyre/